==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ChartGroupDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ChartSortDescriptionDescriptionMetadata } from "./ChartSortDescriptionDescriptionMetadata";
import { ChartGroupDescriptionDescription } from "./ChartGroupDescriptionDescription";
/**
 * @hidden
 */
var ChartGroupDescriptionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ChartGroupDescriptionDescriptionMetadata, _super);
    function ChartGroupDescriptionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChartGroupDescriptionDescriptionMetadata.b = function (a) {
        if (ChartGroupDescriptionDescriptionMetadata.a == null) {
            ChartGroupDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChartGroupDescriptionDescriptionMetadata.c(ChartGroupDescriptionDescriptionMetadata.a);
        }
        if (a.k(ChartGroupDescriptionDescriptionMetadata.a)) {
            return;
        }
        a.ab(ChartGroupDescriptionDescriptionMetadata.a);
    };
    ChartGroupDescriptionDescriptionMetadata.c = function (a) {
        ChartSortDescriptionDescriptionMetadata.c(a);
    };
    ChartGroupDescriptionDescriptionMetadata.d = function (a) {
        ChartGroupDescriptionDescriptionMetadata.b(a);
        a.ad("ChartGroupDescription", function () { return new ChartGroupDescriptionDescription(); });
        a.ac("ChartGroupDescription", ChartGroupDescriptionDescriptionMetadata.a);
    };
    ChartGroupDescriptionDescriptionMetadata.$t = markType(ChartGroupDescriptionDescriptionMetadata, 'ChartGroupDescriptionDescriptionMetadata');
    ChartGroupDescriptionDescriptionMetadata.a = null;
    return ChartGroupDescriptionDescriptionMetadata;
}(Base));
export { ChartGroupDescriptionDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/ChartGroupDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ChartSortDescriptionDescriptionMetadata } from "./ChartSortDescriptionDescriptionMetadata";
import { ChartGroupDescriptionDescription } from "./ChartGroupDescriptionDescription";
/**
 * @hidden
 */
var ChartGroupDescriptionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ChartGroupDescriptionDescriptionMetadata, _super);
    function ChartGroupDescriptionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChartGroupDescriptionDescriptionMetadata.b = function (a) {
        if (ChartGroupDescriptionDescriptionMetadata.a == null) {
            ChartGroupDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChartGroupDescriptionDescriptionMetadata.c(ChartGroupDescriptionDescriptionMetadata.a);
        }
        if (a.k(ChartGroupDescriptionDescriptionMetadata.a)) {
            return;
        }
        a.ac(ChartGroupDescriptionDescriptionMetadata.a);
    };
    ChartGroupDescriptionDescriptionMetadata.c = function (a) {
        ChartSortDescriptionDescriptionMetadata.c(a);
        a.item("__marshalByValue", "Boolean");
    };
    ChartGroupDescriptionDescriptionMetadata.d = function (a) {
        ChartGroupDescriptionDescriptionMetadata.b(a);
        a.ae("ChartGroupDescription", function () { return new ChartGroupDescriptionDescription(); });
        a.ad("ChartGroupDescription", ChartGroupDescriptionDescriptionMetadata.a);
    };
    ChartGroupDescriptionDescriptionMetadata.$t = markType(ChartGroupDescriptionDescriptionMetadata, 'ChartGroupDescriptionDescriptionMetadata');
    ChartGroupDescriptionDescriptionMetadata.a = null;
    return ChartGroupDescriptionDescriptionMetadata;
}(Base));
export { ChartGroupDescriptionDescriptionMetadata };
